==> campsite-2.4.1.tbz: campsite/www-common/html/priv/lang/sr/issues.php <==
<?php
regGS("Issue List", "Листа издања");
regGS("Name<BR><SMALL>(click to see sections)</SMALL>", "Назив<br><small>(кликните за преглед рубрика)</small>");
regGS("Published<BR><SMALL>(yyyy-mm-dd)</SMALL>", "Објављен <br><small>(гггг-мм-дд)</small>");
regGS("Delete issue $1", "Обриши издање $1");
regGS("Publish articles", "Објави чланке");
regGS("Change issue status", "Промени статус издања");
regGS("You do not have the right to change issues.", "Немате право да мењате податке о издању");
regGS("Are you sure you want to change the issue $1 status from $2 to $3?", "Да ли сте сигурни да желите да ппромените статус издања $1 из $2 у $3?");
regGS("Add new translation", "Додај нови превод");
regGS("You do not have the right to add issues.", "Немате право да додајете издања");
regGS("The issue $1 has been successfuly added.", "Издање $1 је успешно додато");
regGS("The issue could not be added.", "Издање не може бити додато");
regGS("Please check if another issue with the same number/language does not already exist.", "Проверите да ли постоји издање заведено под истим бројем/језиком");
regGS("Change issue details", "Промени детаље о издању");
regGS("You do not have the right to change issue details.", "Немате право да мењате податке о издању");
regGS("Publication date<BR><SMALL>(yyyy-mm-dd)</SMALL>", "Датум објављивања<br><small>(гггг-мм-дд)</small>");
regGS("Front Page Template", "Шаблон за почетну страну");
regGS("Issue $1 updated in publication $2", "Издање $1 је измењено у публикацији $2");
regGS("You do not have the right to delete issues.", "Немате право да бришете издања");
regGS("Are you sure you want to delete the issue $1?", "Сигурни сте да желите да обришете издање $1?");
regGS("Deleting issue", "Брисање издања");
regGS("Use the structure of the previous issue", "Искористи структуру претходног издања");
regGS("Copy the entire structure in all languages from the previous issue except for content.", "Прекопирај целокупну структуру у свим језицима из претходног издања, осим садржаја");
regGS("You may modify it later if you wish.", "Можете га променити и касније ако желите");
regGS("Create a new structure", "Направи нову структуру");
regGS("Create a complete new structure.", "Направи потпуно нову структуру");
regGS("You must define an issue type for each language and then sections for them.", "Морате дефинисати тип издања за сваки језик а потом и његове одељке");
regGS("Copy previous issue", "Прекопирај претходно издање");
regGS("No previous issue.", "Нема претходног издања");
regGS("Copy structure from issue nr $1", "Прекопирај структуру из издања $1");
regGS("Copying previous issue", "Копирање претходног издања");
regGS("Select the issue", "Изаберите издање");
regGS("New issue $1 from $2 in publication $3", "Ново издање $1 из $2 у публикацији $3");
regGS("Adding new issue", "Додавање новог издања");
regGS("Delete entry", "Обриши унос");
regGS("Issue Publishing Schedule", "Распоред аутоматског објављивања издања");
regGS("Invalid Input: $1", "Погрешан унос: $1");
regGS("Issue Number", "Број издања");
regGS("Go To Sections", "Иди на рубрике");
regGS("Issue automatic publishing schedule", "Распоред аутоматског објављивања издања");
regGS("Changing issue status", "Мењање статуса издања");
regGS("Status of the issue $1 has been changed from $2 to $3", "Статус издања $1 је промењен из $2 у $3");
regGS("Status of the issue $1 could not be changed.", "Статус издања $1 не може бити измењен");
regGS("Updating issue", "Мењање издања");
regGS("Changing issue's details", "Промена података о издању");
regGS("The issue $1 has been successfuly changed.", "Издање $1 је успешно промењено");
regGS("The issue could not be changed.", "Издање не може бити измењено");
regGS("Changing issue template", "Мењање шаблона за издање");
regGS("You do not have the right to change issue templates.", "Немате право да мењате шаблоне за издање");
regGS("Changing issue template for front page", "Мењање шаблона издања за почетну страну");
regGS("Changing issue template for single article", "Мењање шаблона издања за страну са чланком");
regGS("The template has been successfully changed.", "Шаблон је успешно промењен");
regGS("Issue template for publication $1 changed to $2", "Шаблон издања за публикацију $1 промењен у $2");
regGS("Issue template for single articles from $1 changed to $2", "Шаблон издања за страну са текстом из $1 промењен у $2");
regGS("The template could not be changed.", "Шаблон не може бити промењен");
?>

==> campsite-2.6.1.tbz: campsite/www-common/html/priv/lang/sr/issues.php <==
<?php 
regGS("Change issue status", "");
regGS("The values you are trying to set conflict with issue \"$1$2. $3 ($4)$5\".", "");
regGS("The number must be unique for each issue in this publication of the same language.", "");
regGS("The language and URL name must be unique for each issue in this publication.", "");
regGS("Issue created.", "");
regGS("Issue updated", "");
regGS("Could not save the changes to the issue.", "");
regGS("Unpublish on: $1", "");
regGS("There are $1 articles in this issue.", "");
regGS("The issue $1 has been deleted.", "");
regGS("Schedule", "");
regGS("Publish on: $1", "");
regGS("Publish Date $1", "");
regGS("Deleted issue", "");
regGS("Delete issue", "");
regGS("Click here to publish this issue", "");
regGS("A total of $1 articles were deleted.", "");
regGS("Name<BR><SMALL>(click to see sections)</SMALL>", "Назив<br><small>(кликните за преглед рубрика)</small>");
regGS("Delete issue $1", "Обриши издање $1");
regGS("Publish articles", "Објави текстове");
regGS("You do not have the right to change issues.", "Немате право да мењате податке о издању");
regGS("Are you sure you want to change the issue $1 status from $2 to $3?", "Да ли сте сигурни да желите да промените статус издања $1 из $2 у $3?");
regGS("Add new translation", "Додај нови превод");
regGS("You do not have the right to add issues.", "Немате право да додајете издања");
regGS("The issue $1 has been successfuly added.", "Издање $1 је успешно додато");
regGS("The issue could not be added.", "Издање не може бити додато");
regGS("Change issue details", "Промени детаље о издању");
regGS("You do not have the right to change issue details.", "Немате право да мењате податке о издању");
regGS("Publication date<BR><SMALL>(yyyy-mm-dd)</SMALL>", "Датум објављивања<br><small>(гггг-мм-дд)</small>");
regGS("Front Page Template", "Шаблон за почетну страну");
regGS("Issue $1 updated in publication $2", "Издање $1 је измењено у публикацији $2");
regGS("You do not have the right to delete issues.", "Немате право да бришете издања");
regGS("Are you sure you want to delete the issue $1?", "Сигурни сте да желите да обришете издање $1?");
regGS("Use the structure of the previous issue", "Искористи структуру претходног издања");
regGS("Copy the entire structure in all languages from the previous issue except for content.", "Прекопирај целокупну структуру у свим језицима из претходног издања, осим садржаја");
regGS("You may modify it later if you wish.", "Можете га променити и касније ако желите");
regGS("Create a new structure", "Направи нову структуру");
regGS("Create a complete new structure.", "Направи потпуно нову структуру");
regGS("You must define an issue type for each language and then sections for them.", "Морате дефинисати тип издања за сваки језик а потом и његове одељке");
regGS("Copy previous issue", "Прекопирај претходно издање");
regGS("No previous issue.", "Нема претходног издања");
regGS("Copy structure from issue number $1", "Прекопирај структуру из издања $1");
regGS("New issue $1 from $2 in publication $3", "Ново издање $1 из $2 у публикацији $3");
regGS("Delete entry", "Обриши унос");
regGS("Issue Publishing Schedule", "Распоред аутоматског објављивања издања");
regGS("Invalid Input: $1", "Погрешан унос: $1");
regGS("Issue Number", "Број издања");
regGS("Go To Sections", "Иди на рубрике");
regGS("Issue automatic publishing schedule", "Распоред аутоматског објављивања издања");
regGS("Changing issue status", "Мењање статуса издања");
regGS("Status of the issue $1 has been changed from $2 to $3", "Статус издања $1 је промењен из $2 у $3");
regGS("Status of the issue $1 could not be changed.", "Статус издања $1 не може бити измењен");
regGS("Updating issue", "Мењање издања");
regGS("Changing issue's details", "Промена података о издању");
regGS("The issue $1 has been successfuly changed.", "Издање $1 је успешно промењено");
regGS("The issue could not be changed.", "Издање не може бити измењено");
regGS("Changing issue template", "Мењање шаблона за издање");
regGS("You do not have the right to change issue templates.", "Немате право да мењате шаблоне за издање");
regGS("Changing issue template for front page", "Мењање шаблона издања за почетну страну");
regGS("Changing issue template for single article", "Мењање шаблона издања за страну са приказом целог текста");
regGS("The template has been successfully changed.", "Шаблон је успешно промењен");
regGS("Issue template for publication $1 changed to $2", "Шаблон издања за публикацију $1 промењен у $2");
regGS("Issue template for single articles from $1 changed to $2", "Шаблон издања за страну са текстом из $1 промењен у $2");
regGS("The template could not be changed.", "Шаблон не може бити промењен");
regGS("There was an error reading the language parameter.", "Дошло је до грешке при читању параметра језика.");
regGS("There was an error reading the publication parameter.", "Дошло је до грешке при читању параметра публикације.");
regGS("There was an error reading the issue parameter.", "Дошло је до грешке при читању параметра издања.");
regGS("There was an error scheduling the $1 action on $2", "Дошло је до грешке у заказивању акције $1 за $2");
regGS("The action scheduled on $1 could not be deleted.", "Акција заказана за $1 не може бити обрисана.");
?>
